Coordinate class

A screen position, measured in rows and columns from the top-left origin of the screen. Coordinates are zero-based, and converted as necessary for the underlying system representation (e.g. one-based for VT-style displays).

Inheritance

Constructors

Coordinate(int row, int col)
const

Properties

col → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
magnitude → double
Get the straight line (Euclidean) distance between the origin (0, 0) and this point.
no setterinherited
row → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
finalinherited
y → int
finalinherited

Methods

distanceTo(Point<int> other) → double
Returns the distance between this and other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
squaredDistanceTo(Point<int> other) → int
Returns the squared distance between this and other.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(num factor) → Point<int>
Scale this point by factor as if it were a vector.
inherited
operator +(Point<int> other) → Point<int>
Add other to this, as if both points were vectors.
inherited
operator -(Point<int> other) → Point<int>
Subtract other from this, as if both points were vectors.
inherited
operator ==(Object other) → bool
Whether other is a point with the same coordinates as this point.
inherited