Key class

A representation of a keystroke.

Constructors

Key.control(ControlCharacter controlChar)
Key.printable(String char)

Properties

char ↔ String
getter/setter pair
controlChar ↔ ControlCharacter
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isControl ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited